canvas_image

Function canvas_image 

pub fn canvas_image(x: f32, y: f32, w: f32, h: f32, data: &[u8])
Draw an image on the canvas from encoded image bytes (PNG, JPEG, GIF, WebP). The browser decodes the image and renders it at the given rectangle.