pub fn folder_pick(title: &str) -> Option<u32>Expand description
Open the native folder picker and return a directory handle.
Returns None if the user cancels. Use folder_entries to list the
selected directory.
pub fn folder_pick(title: &str) -> Option<u32>Open the native folder picker and return a directory handle.
Returns None if the user cancels. Use folder_entries to list the
selected directory.