pub fn rtc_poll_track(peer_id: u32) -> Option<RtcTrackInfo>Expand description
Poll for a remote media track added by the peer.
Returns None when no new tracks are pending.
pub fn rtc_poll_track(peer_id: u32) -> Option<RtcTrackInfo>Poll for a remote media track added by the peer.
Returns None when no new tracks are pending.