pub fn worker_post_message(handle: u32, data: &[u8]) -> i32Expand description
Send a message to a worker spawned with spawn_worker.
Returns 0 on success, -1 if the handle is unknown.
pub fn worker_post_message(handle: u32, data: &[u8]) -> i32Send a message to a worker spawned with spawn_worker.
Returns 0 on success, -1 if the handle is unknown.