ui_button

Function ui_button 

pub fn ui_button(id: u32, x: f32, y: f32, w: f32, h: f32, label: &str) -> bool
Render a button at the given position. Returns true if it was clicked on the previous frame.

Must be called from on_frame() — widgets are only rendered for interactive applications that export a frame loop.